==> nextcloud-app-richdocuments-1.1.25-3-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/richdocuments/l10n/de_DE.js <==
OC.L10N.register(
    "richdocuments",
    {
    "Saving..." : "Speichervorgang…",
    "Download this revision" : "Diese Revision herunterladen",
    "Restore this revision" : "Diese Revision wiederherstellen",
    "Latest revision" : "Letzte Revision",
    "More versions..." : "Weitere Versionen…",
    "Just now" : "Gerade ebend",
    "Failed to revert the document to older version" : "Fehler beim Zurüclsetzen des Dokumentes auf eine ältere Version",
    "Save" : "Speichern",
    "Loading documents..." : "Lade Dokumente…",
    "Edit" : "Bearbeiten",
    "View" : "Ansicht",
    "Document" : "Dokument",
    "Spreadsheet" : "Kalkulationstabelle",
    "Presentation" : "Präsentation",
    "Could not create file" : "Die Datei konnte nicht erstellt werden",
    "New Document.odt" : "Neues Dokument.odt",
    "New Spreadsheet.ods" : "Neue Kalkulationstabelle.ods",
    "New Presentation.odp" : "Neue Präsentation.odp",
    "New Document.docx" : "Neues Dokument.docx",
    "New Spreadsheet.xlsx" : "Neue Tabelle.xlsx",
    "New Presentation.pptx" : "Neue Präsentation.pptx",
    "Can't create document" : "Dokument kann nicht erstellt werden",
    "Saved" : "Gespeichert",
    "Saved with error: Collabora Online should use the same protocol as the server installation." : "Mit Fehler gespeichert: Collabora Online sollte das gleiche Protokoll wie die Server-Installation nutzen.",
    "Collabora Online" : "Collabora Online",
    "Collabora Online server" : "Collabora Online Server",
    "URL (and port) of the Collabora Online server that provides the editing functionality as a WOPI client." : "URL (und Port) des Collabora Online Servers unterstützt die Editierfunktions als WOPI-Client.",
    "Apply" : "Anwenden",
    "Use OOXML by default for new files" : "OOXML als Standard für neue Dateien nutzen",
    "Wrong password. Please retry." : "Falsches Passwort. Bitte versuchen Sie es noch einmal.",
    "Password" : "Passwort",
    "OK" : "OK",
    "Guest %s" : "Gast %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Dieser Link ist abgelaufen oder existierte niemals. Bitte kontaktieren Sie für nähere Details die Person, die dieses Dokument mit Ihnen geteilt hat."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-richdocuments-1.12.31-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/richdocuments/l10n/de_DE.js <==
OC.L10N.register(
    "richdocuments",
    {
    "Saving..." : "Speichere…",
    "Download this revision" : "Diese Revision herunterladen",
    "Restore this revision" : "Diese Revision wiederherstellen",
    "Latest revision" : "Neueste Revision",
    "More versions..." : "Weitere Versionen…",
    "Just now" : "Gerade ebend",
    "Failed to revert the document to older version" : "Fehler beim Zurüclsetzen des Dokumentes auf eine ältere Version",
    "Save" : "Speichern",
    "Loading documents..." : "Lade Dokumente…",
    "Edit" : "Bearbeiten",
    "New Document" : "Neues Dokument",
    "New Spreadsheet" : "Neue Tabelle",
    "New Presentation" : "Neue Präsentation",
    "Could not create file" : "Die Datei konnte nicht erstellt werden",
    "New Document.odt" : "Neues Dokument.odt",
    "New Spreadsheet.ods" : "Neue Kalkulationstabelle.ods",
    "New Presentation.odp" : "Neue Präsentation.odp",
    "New Document.docx" : "Neues Dokument.docx",
    "New Spreadsheet.xlsx" : "Neue Tabelle.xlsx",
    "New Presentation.pptx" : "Neue Präsentation.pptx",
    "Can't create document" : "Dokument kann nicht erstellt werden",
    "Saved" : "Gespeichert",
    "Saved with error: Collabora Online should use the same protocol as the server installation." : "Mit Fehler gespeichert: Collabora Online sollte das gleiche Protokoll wie die Server-Installation nutzen.",
    "Collabora Online" : "Collabora Online",
    "Collabora Online server" : "Collabora Online Server",
    "URL (and port) of the Collabora Online server that provides the editing functionality as a WOPI client." : "URL (und Port) des Collabora Online Servers unterstützt die Editierfunktions als WOPI-Client.",
    "Apply" : "Anwenden",
    "Use OOXML by default for new files" : "OOXML als Standard für neue Dateien nutzen",
    "Wrong password. Please retry." : "Falsches Passwort. Bitte versuchen Sie es noch einmal.",
    "Password" : "Passwort",
    "OK" : "OK",
    "Guest %s" : "Gast %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Dieser Link ist abgelaufen oder existierte niemals. Für weitere Details kontaktiern Sie bitte denjenigen, der das Dokument mit Ihnen geteilt hat."
},
"nplurals=2; plural=(n != 1);");
